django-q3c
==========

django-q3c is python package to add support for the q3c
(https://github.com/segasai/q3c) PostgreSQL extension to
the django ORM. This allows for spherical indexing for faster queries, and
avoids the need for manual SQL usage (thereby increasing security by avoiding
SQL injection attacks).
